# DataJoint SciOps Customer Tools

A suite of customer CLI tools for DataJoint SciOps.

# Python Requirement

Djsciops requires a minimum python version of `3.8`

# GUI
## Preview
![image](https://user-images.githubusercontent.com/61991709/179300351-95dff3c9-d412-437b-9678-a4182ace81dc.png)
![image](https://user-images.githubusercontent.com/61991709/179300363-21a496ee-a0be-456c-ab16-6668d5458d5c.png)

## Installation
### Windows
1. Extract the `Axon.exe` to the desired directory
2. Run `Axon.exe`
3. If Windows Defender notifies you that the app is unrecognized, click `More info`, then `Run anyway`
4. When authenticating, if Windows Firewall notifies you that network access has been blocked, click `Allow access`

### MacOS
1. Extract the `Axon.dmg` to the desired directory
2. Open `Axon.dmg`
3. Move `Axon.app` to your Applications folder
4. Run `Axon`
5. If `Axon` is blocked from opening, click `OK`
6. Navigate to `System Preferences` -> `Security & Privacy` -> `General`
8. Click `Open Anyway`
